mathtools.partition_integer_into_canonic_parts
==============================================

.. autofunction:: abjad.tools.mathtools.partition_integer_into_canonic_parts.partition_integer_into_canonic_parts
